#!/bin/bash -e 
echo $0

. $(dirname $0)/../env-common

# Make tarball of jobs dirs and config.xml from jenkins master, pull it to
# local home.  Tarball names are timestamped.  Useful for backing up job
# configs without workspaces, history, artifacts, etc.

loc_dir="${HOME}/tmp.jobs"
mkdir -p $loc_dir
tmp_file="$(mktemp)"

cat > "$tmp_file" << "EOF"
d_str=$(date +"%Y%m%d%H%M%S%N")
jobs_dir="/var/lib/jenkins/jobs"
jobs_bare="${jobs_dir}-${d_str}"
tarball="jobs-${d_str}.tgz"
u_home="/home/ubuntu"
u_own="ubuntu:ubuntu"

mkdir -p $jobs_bare

for f in ${jobs_dir}/* ; do 
  if [ -d "$f" ]; then
    new_job_dir=${jobs_bare}/$(basename ${f})
    mkdir -p ${new_job_dir}
    cp -f ${f}/config.xml ${new_job_dir}
  fi
done

tar -cvzf ${tarball} -C ${jobs_bare} .
sudo cp -fv ${tarball} ${u_home}
sudo chown $u_own ${u_home}/${tarball}
echo "${u_home}/${tarball}"
EOF

sudo chmod 770 $tmp_file

f_dst="${U_HOME}/bare-copy-jobs.sh"
f_src="$tmp_file"

# Copy script into master and execute
juju scp $f_src ${MASTER}:${f_dst}
juju ssh ${MASTER} "sudo ${U_HOME}/bare-copy-jobs.sh"
juju scp ${MASTER}:jobs-*.tgz ${loc_dir}

echo "Jobs files in ${loc_dir}:"
ls -al ${loc_dir}
