#!/bin/bash -e

# Source the common functions
. ${OSCI_ROOT}/job-parts/osci_job_common.sh

f_fresh_clean_start
f_tool_refresh_bot_control
f_amulet_set_network_env_vars
f_env_no_pass
f_check_out_universal

# Required for layerci
f_tool_refresh_release_tools
f_tool_refresh_bot_control
f_layerci_use_built_asset_if_relevant
f_layerci_fail_if_not_deployable_type

# Gerrit-triggered jobs will pass GERRIT_BRANCH, while other legacy
# jobs will pass GIT_BRANCH.
if [[ -z "$SUPPORTED_SERIES" ]] && [[ "$GERRIT_BRANCH" != *stable* ]] && [[ "$GIT_BRANCH" != *stable* ]]; then
  # Master (dev)
  export SUPPORTED_SERIES="xenial"
elif [[ -z "$SUPPORTED_SERIES" ]] && [[ "$GERRIT_BRANCH" != "master" ]] && [[ "$GIT_BRANCH" != "master" ]]; then
  # Stable (released)
  export SUPPORTED_SERIES="xenial"
else
  echo " ! Unable to determine SUPPORTED_SERIES based on GERRIT_BRANCH and/or GIT_BRANCH values"
  exit 1
fi

f_line "Begin test charm single for: $SUPPORTED_SERIES"

# Check for skipfile in central bot-control repo
SKIP_SINGLE="${UOSCI_BOT_CONTROL_ROOT}/config/charm-single/$BASE_NAME.skip"
if [[ -f "$SKIP_SINGLE" ]]; then
  echo " ! Skipping charm-single for $BASE_NAME per bot-control"
  cat $SKIP_SINGLE
  cp -fv $SKIP_SINGLE $WORKSPACE/charm-single.skip
  exit 0
fi

f_juju_bootstrap
export DEPLOY_DIR=$(mktemp -d)


for RELEASE in $SUPPORTED_SERIES; do
  # Prep charm series dirs
  echo " + Copying ${BUILT_ASSET_DIR-$CO_DIR}/ --> $DEPLOY_DIR/$RELEASE/$BASE_NAME/"
  mkdir -p $DEPLOY_DIR/$RELEASE/$BASE_NAME
  cp -rfp ${BUILT_ASSET_DIR-$CO_DIR}/* $DEPLOY_DIR/$RELEASE/$BASE_NAME/
  juju_svc_name="$BASE_NAME-${RELEASE::1}"

  # Deploy
  echo " + Deploying the $BASE_NAME charm as Juju service: \"$juju_svc_name\" on $RELEASE"
  juju deploy --repository=$DEPLOY_DIR local:$RELEASE/$BASE_NAME $juju_svc_name


  # Use a series-named config yaml file if it exists, otherwise look for charmname.yaml
  YAML_BY_RELEASE="${UOSCI_BOT_CONTROL_ROOT}/config/charm-single/$BASE_NAME-$RELEASE.yaml"
  YAML_BY_BASENAME="${UOSCI_BOT_CONTROL_ROOT}/config/charm-single/$BASE_NAME.yaml"

  if [[ -f "$YAML_BY_RELEASE" ]]; then
    CHARM_SINGLE_YAML="$YAML_BY_RELEASE"
  elif [[ -f "$YAML_BY_BASENAME" ]]; then
    CHARM_SINGLE_YAML="$YAML_BY_BASENAME"
  else
    echo " . No charm-single config yaml to apply for $BASE_NAME"
    CHARM_SINGLE_YAML=""
  fi

  # Configure if override exists
  if [[ ! -z "$CHARM_SINGLE_YAML" ]]; then
    echo " + Rendering file: $CHARM_SINGLE_YAML"
    ${UOSCI_BOT_CONTROL_ROOT}/tools/env-render -vy $CHARM_SINGLE_YAML
    sed -e "s/^$BASE_NAME:/$juju_svc_name:/" -i $CHARM_SINGLE_YAML
    cp $CHARM_SINGLE_YAML $WORKSPACE/$juju_svc_name.yaml.txt

    echo " + Setting juju config on $juju_svc_name from $CHARM_SINGLE_YAML"
    cat $2 $CHARM_SINGLE_YAML
    echo ""
    juju set $juju_svc_name --config=$CHARM_SINGLE_YAML

    cd $UOSCI_BOT_CONTROL_ROOT
    git reset --hard
    cd $WORKSPACE
  fi
done

# Wait for juju units to complete hooks
# Force initial wait, then do juju_wait twice to be convinced.  Not a typo.
sleep 60
f_juju_wait
f_juju_wait

# Check basic connectivity of every juju unit
f_juju_status_health_check

f_line "Cleaning up deployer temp directories"
echo " - Removing dir: $DEPLOYER_DIR"
echo " - Removing dir: ${BUILT_ASSET_DIR-$CO_DIR}"
cd $WORKSPACE
rm -rf $DEPLOY_DIR
rm -rf ${BUILT_ASSET_DIR-$CO_DIR}
f_line "End test charm single"

f_collect_juju_logs
f_set_build_descr
f_nice_finish
f_check_fail
