#!/bin/bash -e
#  Mojo runner for UOSCI

# Define defaults for manual runs outside of a Jenkins environment
#[[ -z "$" ]] && export =""
[[ -z "$JENKINS_HOME" ]] && export JENKINS_HOME="$HOME"
[[ -z "$WORKSPACE" ]] && export WORKSPACE="$(mktemp -d)"
[[ -z "$BUILD_NUMBER" ]] && export BUILD_NUMBER="manual"

[[ -z "$OSCI_REPO" ]] && export OSCI_REPO="lp:ubuntu-openstack-ci"
[[ -z "$OSCI_ROOT" ]] && export OSCI_ROOT="${HOME}/tools/ubuntu-openstack-ci"

[[ -z "$OPENSTACK_CHARM_TESTING_REPO" ]] && export OPENSTACK_CHARM_TESTING_REPO="lp:openstack-charm-testing"
[[ -z "$OPENSTACK_CHARM_TESTING_ROOT" ]] && export OPENSTACK_CHARM_TESTING_ROOT="${HOME}/tools/openstack-charm-testing"

# /!\ Temporary override for spec dev
[[ -z "$MOJO_OPENSTACK_SPECS_REPO" ]] && export MOJO_OPENSTACK_SPECS_REPO="lp:~ost-maintainers/openstack-mojo-specs/mojo-openstack-specs"

[[ -z "$MOJO_SERIES" ]] && export MOJO_SERIES="trusty"
[[ -z "$MOJO_SPEC" ]] && export MOJO_SPEC="specs/full_stack/next_deploy_baremetal/icehouse"

# Avoid environment teardown if run outside of a Jenkins environment
[[ -z "$BUILD_URL" ]] && export NO_POST_DESTROY="true"

# Source the common functions
. ${OSCI_ROOT}/job-parts/osci_job_common.sh

# Set common, constant mojo workspace and project names
export MOJO_WKSP="osci-mojo"
export MOJO_PROJ="mojo-openstack-specs"
export MOJO_ROOT="$(mktemp -d)"

# Prep environment
f_fresh_clean_start
f_env_no_pass

f_tool_refresh_bot_control
f_mojo_create_venv

f_line "validating mojo runner env vars"
f_mojo_handle_env_vars

f_line "defining new mojo project"
f_mojo_new_project

f_line "defining new mojo workspace"
f_mojo_new_workspace

f_line "check that mojo spec manifest exists"
MOJO_MANIFEST_FILE=${MOJO_ROOT}/${MOJO_PROJ}/${MOJO_SERIES}/${MOJO_WKSP}/spec/${MOJO_SPEC}/manifest
ls -alh $MOJO_MANIFEST_FILE

f_line "bootstrapping"
f_juju_get_pkg_info juju-pkg-info.txt

if [[ "$MOJO_SPEC" == *metal* ]]; then
  # Handle baremetal specs
  export UOSCI_JUJU_TAGS="arch=amd64 tags=uosci"
  juju bootstrap --upload-tools --constraints="${UOSCI_JUJU_TAGS}" 2>&1 | tee $WORKSPACE/juju-bootstrap.$BUILD_NUMBER.txt
  if [[ "${PIPESTATUS[0]}" != "0" ]]; then
    echo " ! Bootstrap failed."
    touch $WORKSPACE/fyi-${test:0:4}.${test}-bootstrap.failed
  fi
else
  # Not baremetal
  f_juju_bootstrap
fi

f_line "run mojo, run!"
f_mojo_run
f_line "end of mojo's run"

# DEBUG: list all running instances and all neutron ports
f_list_nova_instances
f_list_neutron_ports

# Wrap up
f_collect_juju_logs
f_set_build_descr
f_nice_finish
f_check_fail
