#!/bin/bash -e
#
#  Common functions for UOSCI jobs, specific to refreshing tool branches.

function f_tool_refresh_osci() {
# ubuntu_openstack_ci fresh
  if [[ -d $OSCI_ROOT ]]; then
    echo " - Removing existing checkout @ $OSCI_ROOT"
    rm -rf $OSCI_ROOT
  fi
  echo " + Creating new lightweight checkout of $OSCI_REPO @ $OSCI_ROOT."
  bzr co --lightweight $OSCI_REPO $OSCI_ROOT
  echo "revno: $(bzr revno $OSCI_ROOT)"
}


function f_tool_refresh_oct() {
# keep openstack_charm_testing fresh
  if [[ -d $OPENSTACK_CHARM_TESTING_ROOT ]]; then
    echo " - Removing existing checkout of @ $OPENSTACK_CHARM_TESTING_ROOT"
    rm -rf $OPENSTACK_CHARM_TESTING_ROOT
  fi
  echo " + Creating new lightweight checkout of $OPENSTACK_CHARM_TESTING_REPO @ $OPENSTACK_CHARM_TESTING_ROOT."
  bzr co --lightweight $OPENSTACK_CHARM_TESTING_REPO $OPENSTACK_CHARM_TESTING_ROOT
  echo "revno: $(bzr revno $OPENSTACK_CHARM_TESTING_ROOT)"
}


function f_tool_refresh_juju_wait() {
# keep juju_wait fresh
  [[ -z "$JUJU_WAIT_ROOT" ]] && export JUJU_WAIT_ROOT="${HOME}/tools/juju-wait"
#  https://bugs.launchpad.net/juju-wait/+bug/1641163
#  [[ -z "$JUJU_WAIT_REPO" ]] && export JUJU_WAIT_REPO="https://git.launchpad.net/juju-wait"
  [[ -z "$JUJU_WAIT_REPO" ]] && export JUJU_WAIT_REPO="https://git.launchpad.net/~1chb1n/juju-wait"
  [[ -z "$JUJU_WAIT_BRANCH" ]] && export JUJU_WAIT_BRANCH="revert-for-lp1641163"

  if [[ -d $JUJU_WAIT_ROOT ]]; then
    echo " - Removing existing dir @ $JUJU_WAIT_ROOT"
    rm -rf $JUJU_WAIT_ROOT
  fi

  echo " + Creating new shallow clone of $JUJU_WAIT_REPO @ $JUJU_WAIT_ROOT ($JUJU_WAIT_BRANCH)."
  git clone -q --depth=1 $JUJU_WAIT_REPO $JUJU_WAIT_ROOT -b $JUJU_WAIT_BRANCH
  git -C $JUJU_WAIT_ROOT branch -av
  git -C $JUJU_WAIT_ROOT remote -v
}


function f_tool_refresh_migration_tools() {
# Git the migration tools
  [[ -z "$UOSCI_MIG_TOOLS_REPO" ]] && export UOSCI_MIG_TOOLS_REPO="https://github.com/openstack-charmers/migration-tools"
  [[ -z "$UOSCI_MIG_TOOLS_ROOT" ]] && export UOSCI_MIG_TOOLS_ROOT="$HOME/tools/migration-tools"
  [[ -z "$UOSCI_MIG_TOOLS_BRANCH" ]] && export UOSCI_MIG_TOOLS_BRANCH="master"

  if [[ -d $UOSCI_MIG_TOOLS_ROOT ]]; then
    echo " - Removing existing dir @ $UOSCI_MIG_TOOLS_ROOT"
    rm -rf $UOSCI_MIG_TOOLS_ROOT
  fi

  echo " + Creating new shallow clone of $UOSCI_MIG_TOOLS_REPO @ $UOSCI_MIG_TOOLS_ROOT ($UOSCI_MIG_TOOLS_BRANCH)."
  git clone -q --depth=1 $UOSCI_MIG_TOOLS_REPO $UOSCI_MIG_TOOLS_ROOT -b $UOSCI_MIG_TOOLS_BRANCH
  git -C $UOSCI_MIG_TOOLS_ROOT branch -av
  git -C $UOSCI_MIG_TOOLS_ROOT remote -v
}


function f_tool_refresh_bot_control() {
# Git the bot-control repo
  [[ -z "$UOSCI_BOT_CONTROL_REPO" ]] && export UOSCI_BOT_CONTROL_REPO="https://github.com/openstack-charmers/bot-control.git"
  [[ -z "$UOSCI_BOT_CONTROL_ROOT" ]] && export UOSCI_BOT_CONTROL_ROOT="${HOME}/tools/bot-control"
  [[ -z "$UOSCI_BOT_CONTROL_BRANCH" ]] && export UOSCI_BOT_CONTROL_BRANCH="master"

  if [[ -d $UOSCI_BOT_CONTROL_ROOT ]]; then
    echo " - Removing existing dir @ $UOSCI_BOT_CONTROL_ROOT"
    rm -rf $UOSCI_BOT_CONTROL_ROOT
  fi

  echo " + Creating new shallow clone of $UOSCI_BOT_CONTROL_REPO @ $UOSCI_BOT_CONTROL_ROOT ($UOSCI_BOT_CONTROL_BRANCH)"
  git clone -q --depth=1 $UOSCI_BOT_CONTROL_REPO $UOSCI_BOT_CONTROL_ROOT -b $UOSCI_BOT_CONTROL_BRANCH
  git -C $UOSCI_BOT_CONTROL_ROOT branch -av
  git -C $UOSCI_BOT_CONTROL_ROOT remote -v
}


function f_tool_refresh_release_tools() {
# Git the release-tools repo
  [[ -z "$UOSCI_RELEASE_TOOLS_REPO" ]] && export UOSCI_RELEASE_TOOLS_REPO="https://github.com/openstack-charmers/release-tools"
  [[ -z "$UOSCI_RELEASE_TOOLS_ROOT" ]] && export UOSCI_RELEASE_TOOLS_ROOT="${HOME}/tools/release-tools"
  [[ -z "$UOSCI_RELEASE_TOOLS_BRANCH" ]] && export UOSCI_RELEASE_TOOLS_BRANCH="master"

  if [[ -d $UOSCI_RELEASE_TOOLS_ROOT ]]; then
    echo " - Removing existing dir @ $UOSCI_RELEASE_TOOLS_ROOT"
    rm -rf $UOSCI_RELEASE_TOOLS_ROOT
  fi

  echo " + Creating shallow new clone of $UOSCI_RELEASE_TOOLS_REPO @ $UOSCI_RELEASE_TOOLS_ROOT ($UOSCI_RELEASE_TOOLS_BRANCH)"
  git clone -q --depth=1 $UOSCI_RELEASE_TOOLS_REPO $UOSCI_RELEASE_TOOLS_ROOT -b $UOSCI_RELEASE_TOOLS_BRANCH
  git -C $UOSCI_RELEASE_TOOLS_ROOT branch -av
  git -C $UOSCI_RELEASE_TOOLS_ROOT remote -v
}


#function f_tool_refresh_tarmac() {
# keep tarmac fresh
#if [[ -d $TARMAC_ROOT ]]; then
#  echo " - Removing existing checkout @ $TARMAC_ROOT"
#  rm -rf $TARMAC_ROOT
#fi
#echo " + Creating new lightweight checkout of $TARMAC_REPO @ $TARMAC_ROOT."
#bzr co --lightweight $TARMAC_REPO $TARMAC_ROOT
#}


#function f_tool_refresh_osut() {
# Dump juju package info to a file.
# keep openstack_ubuntu_testing fresh
#if [[ -d $OPENSTACK_UBUNTU_ROOT ]]; then
#  echo " - Removing existing checkout of @ $OPENSTACK_UBUNTU_ROOT"
#  rm -rf $OPENSTACK_UBUNTU_ROOT
#fi
#echo " + Creating new lightweight checkout @ $OPENSTACK_UBUNTU_ROOT."
#bzr co --lightweight $OPENSTACK_UBUNTU_REPO $OPENSTACK_UBUNTU_ROOT
#}


function f_tools_refresh() {
  if [[ "${NO_TOOLS_REFRESH^^}" != "TRUE" ]]; then
    f_line "Refreshing UOSCI & O-C-T branches..."
    f_tool_refresh_osci

    if [[ "${SKIP_JUJU_LXC^^}" != "TRUE" ]]; then
      f_tool_refresh_oct
      f_tool_refresh_juju_wait
    fi

  else
    echo " - Not refreshing UOSCI & O-C-T branches due to env var."
  fi
}
